@@ -1,3 +1,5 @@
+use std::collections::HashMap;
+use std::fmt;
 use std::fs::File;
 use std::io::Read;
 use std::path::Path;
@@ -8,10 +10,25 @@ use toml;
 use crate::Result;
 
 #[derive(Debug,Clone,Deserialize)]
-pub struct Config {
+pub struct CommandConfig {
     pub command: String,
+    pub args: Option<Vec<String>>
+}
+
+impl fmt::Display for CommandConfig {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        match self.args {
+            Some(ref args) => write!(f, "{} {}", self.command, args.join(" ")),
+            None => write!(f, "{}", self.command)
+        }
+    }
+}
+
+#[derive(Debug,Clone,Deserialize)]
+pub struct Config {
     pub paths_to_watch: Vec<String>,
-    pub triggers: Option<Vec<String>>
+    pub processes: HashMap<String, CommandConfig>,
+    pub triggers: Option<HashMap<String, CommandConfig>>
 }
 
 impl Config {
